function b=maxmat(a,f);
% maxmat performs a maximum filter over the columns of a. f is the size of
% the filter.
% b : maximum filtered image
% a : input image
% f : filter size
%
[r,c]= size(a);
b=a;
for i1=f+1:r-f
	b(i1,:)=max(a(i1-f:i1+f,:));
end
